<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

use KevinPlugin\Handler\OrderCreationHandler;
use KevinPlugin\Handler\PaymentWebhookHandler;
use KevinPlugin\Handler\RefundWebhookHandler;
use KevinPlugin\Repository\KevinPaymentRepository;
use KevinPlugin\Repository\KevinRefundRepository;
use KevinPlugin\Repository\PsOrderRepository;
use KevinPlugin\Utils\Server;
use KevinPlugin\Utils\Url;
use KevinPluginFramework\Application\KevinConstants;
use KevinPluginFramework\Application\PaymentWebhookVerifier;

class KevinWebhookModuleFrontController extends ModuleFrontController
{
    /**
     * @var Kevin
     */
    public $module;

    /**
     * Process webhook request.
     */
    public function postProcess()
    {
        if (!$this->module->active) {
            http_response_code(500);
            exit('Module not active.');
        }

        $requestJson = Tools::file_get_contents('php://input');
        $request = json_decode($requestJson, true);

        $webhookVerifier = new PaymentWebhookVerifier(
            $this->module->getGatewaySettings()->getEndpointSecret(),
            Url::getWebhookUrl()
        );

        if (!$webhookVerifier->verifySignature(json_encode($request), Server::getAllHeaders())) {
            http_response_code(400);
            exit('Signatures do not match.');
        }

        $webhookType = $request['type'];

        switch ($webhookType) {
            case KevinConstants::WEBHOOK_TYPE_PAYMENT:
                $handler = new PaymentWebhookHandler(
                    new OrderCreationHandler($this->module, new KevinPaymentRepository()),
                    new KevinPaymentRepository(),
                    new PsOrderRepository()
                );
                break;
            case KevinConstants::WEBHOOK_TYPE_REFUND:
                $handler = new RefundWebhookHandler(
                    $this->module->getGatewaySettings(),
                    new KevinRefundRepository(),
                    new KevinPaymentRepository(),
                    new PsOrderRepository()
                );
                break;
            default:
                http_response_code(400);
                exit('Unrecognized webhook type.');
        }

        try {
            $result = $handler->handle($request);
        } catch (\Exception $e) {
            http_response_code(500);
            exit($e->getMessage());
        }

        if ($result['isSuccess'] === true) {
            http_response_code(200);
        } else {
            http_response_code(400);
        }

        exit($result['message']);
    }
}
