<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin\Form\Settings\Subform;

if (!defined('_PS_VERSION_')) {
    exit;
}

use KevinPlugin\GatewaySettings;
use KevinPlugin\Utils\PsVersionHelper;
use KevinPlugin\Utils\Translator;
use KevinPluginFramework\Presentation\Admin\Form\BuildGuideline\CheckoutSettingsFormBuildGuideline;

class CheckoutSettingsSubform implements SubformInterface
{
    const SUBMIT_NAME = 'submitCheckoutSettings';

    /**
     * @var CheckoutSettingsFormBuildGuideline
     */
    private $buildGuideline;

    /**
     * @var FormField[]
     */
    private $formFields;

    public function __construct(CheckoutSettingsFormBuildGuideline $buildGuideline)
    {
        $this->buildGuideline = $buildGuideline;
        $this->initFormFields();
    }

    public function toArray()
    {
        $formFields = [];
        foreach ($this->formFields as $formField) {
            $formFields[] = $formField->toArray();
        }

        return [
            'form' => [
                'legend' => [
                    'title' => Translator::translate($this->buildGuideline->getName()),
                    'icon' => 'icon-cogs',
                ],
                'input' => $formFields,
                'submit' => [
                    'title' => Translator::translate('Save'),
                    'name' => self::SUBMIT_NAME,
                ],
            ],
        ];
    }

    public function getSubmitName()
    {
        return self::SUBMIT_NAME;
    }

    public function getFormFields()
    {
        return $this->formFields;
    }

    private function initFormFields()
    {
        foreach ($this->buildGuideline->getFormFieldBuildGuidelines() as $formFieldBuildGuideline) {
            if ($formFieldBuildGuideline->getName() === CheckoutSettingsFormBuildGuideline::FIELD_NAME_WHITE_BANK_LOGOS) {
                continue;
            }
            if (PsVersionHelper::isPre17Version()) {
                if ($formFieldBuildGuideline->getName() === CheckoutSettingsFormBuildGuideline::FIELD_NAME_CHECKOUT_VIEW) {
                    $options = $formFieldBuildGuideline->getOptions();
                    unset($options['tiles']);
                    $formFieldBuildGuideline->setOptions($options);
                }
            }
            $this->formFields[] = FormFieldBuilder::buildFromGuideline($formFieldBuildGuideline);
        }
    }
}
