<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Configuration;
use KevinPluginFramework\Presentation\Admin\Form\BuildGuideline\CheckoutSettingsFormBuildGuideline;

class GatewaySettings
{
    const KEVIN_ENABLED = 'KEVIN_ENABLED';
    const KEVIN_CLIENT_ID = 'KEVIN_CLIENT_ID';
    const KEVIN_CLIENT_SECRET = 'KEVIN_CLIENT_SECRET';
    const KEVIN_ENDPOINT_SECRET = 'KEVIN_ENDPOINT_SECRET';
    const KEVIN_CREDITOR_NAME = 'KEVIN_CREDITOR_NAME';
    const KEVIN_CREDITOR_ACCOUNT = 'KEVIN_CREDITOR_ACCOUNT';
    const KEVIN_BANK_SEARCH = 'KEVIN_BANK_SEARCH';
    const KEVIN_COUNTRY_DROPDOWN = 'KEVIN_COUNTRY_DROPDOWN';
    const KEVIN_CHECKOUT_VIEW = 'KEVIN_CHECKOUT_VIEW';

    const KEVIN_ORDER_STATUS_STARTED = 'KEVIN_ORDER_STATUS_STARTED';
    const KEVIN_ORDER_STATUS_PENDING = 'KEVIN_ORDER_STATUS_PENDING';
    const KEVIN_ORDER_STATUS_PARTIAL_REFUND = 'KEVIN_ORDER_STATUS_PARTIAL_REFUND';

    private $enabled;
    private $clientId;
    private $clientSecret;
    private $creditorName;
    private $creditorAccount;
    private $endpointSecret;
    private $checkoutView;
    private $countryDropdown;
    private $bankSearch;

    public function __construct()
    {
        $values = Configuration::getMultiple(self::getAllKeys());
        $this->enabled = (bool) $values[self::KEVIN_ENABLED];
        $this->clientId = $values[self::KEVIN_CLIENT_ID] ?: null;
        $this->clientSecret = $values[self::KEVIN_CLIENT_SECRET] ?: null;
        $this->endpointSecret = $values[self::KEVIN_ENDPOINT_SECRET] ?: null;
        $this->creditorName = $values[self::KEVIN_CREDITOR_NAME] ?: null;
        $this->creditorAccount = $values[self::KEVIN_CREDITOR_ACCOUNT] ?: null;
        $this->checkoutView = $values[self::KEVIN_CHECKOUT_VIEW] ?: null;
        $this->countryDropdown = (bool) $values[self::KEVIN_COUNTRY_DROPDOWN];
        $this->bankSearch = (bool) $values[self::KEVIN_BANK_SEARCH];
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return $this->enabled;
    }

    /**
     * @return mixed
     */
    public function getClientId()
    {
        return $this->clientId;
    }

    /**
     * @return mixed
     */
    public function getClientSecret()
    {
        return $this->clientSecret;
    }

    /**
     * @return mixed
     */
    public function getCreditorName()
    {
        return $this->creditorName;
    }

    /**
     * @return mixed
     */
    public function getCreditorAccount()
    {
        return $this->creditorAccount;
    }

    /**
     * @return mixed
     */
    public function getEndpointSecret()
    {
        return $this->endpointSecret;
    }

    /**
     * @return mixed
     */
    public function getCheckoutView()
    {
        return $this->checkoutView;
    }

    /**
     * @return bool
     */
    public function isCheckoutViewFrame()
    {
        return $this->getCheckoutView() === CheckoutSettingsFormBuildGuideline::CHECKOUT_VIEW_OPTION_FRAME;
    }

    /**
     * @return bool
     */
    public function isCheckoutViewList()
    {
        return $this->getCheckoutView() === CheckoutSettingsFormBuildGuideline::CHECKOUT_VIEW_OPTION_LIST;
    }

    /**
     * @return bool
     */
    public function isCheckoutViewTiles()
    {
        return $this->getCheckoutView() === CheckoutSettingsFormBuildGuideline::CHECKOUT_VIEW_OPTION_TILES;
    }

    /**
     * @return bool
     */
    public function isCountryDropdown()
    {
        return $this->countryDropdown;
    }

    /**
     * @return bool
     */
    public function isBankSearch()
    {
        return $this->bankSearch;
    }

    /**
     * @return int
     */
    public function getOrderStatusKevinStartedId()
    {
        return (int) Configuration::get(self::KEVIN_ORDER_STATUS_STARTED);
    }

    /**
     * @return int
     */
    public function getOrderStatusKevinPendingId()
    {
        return (int) Configuration::get(self::KEVIN_ORDER_STATUS_PENDING);
    }

    /**
     * @return int
     */
    public function getOrderStatusKevinPartialRefundId()
    {
        return (int) Configuration::get(self::KEVIN_ORDER_STATUS_PARTIAL_REFUND);
    }

    /**
     * @return array
     */
    public static function getAllKeys()
    {
        return [
            self::KEVIN_ENABLED,
            self::KEVIN_CLIENT_ID,
            self::KEVIN_CLIENT_SECRET,
            self::KEVIN_ENDPOINT_SECRET,
            self::KEVIN_CREDITOR_NAME,
            self::KEVIN_CREDITOR_ACCOUNT,
            self::KEVIN_BANK_SEARCH,
            self::KEVIN_COUNTRY_DROPDOWN,
            self::KEVIN_CHECKOUT_VIEW
        ];
    }
}
