<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin\Repository;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Db;
use Tools;

class KevinPaymentRepository
{
    /**
     * @var Db
     */
    private $db;

    public function __construct()
    {
        $this->db = Db::getInstance();
    }

    public function add($kevinPaymentId, $kevinStatusGroup, $paymentType, $cartId)
    {
        $this->db->insert('kevin', [
            'payment_id' => pSQL($kevinPaymentId),
            'status_group' => pSQL($kevinStatusGroup),
            'created_at' => (new \DateTime())->format('Y-m-d H:i:s'),
            'payment_type' => $paymentType,
            'ip_address' => pSQL(Tools::getRemoteAddr()),
            'id_cart' => $cartId,
        ]);
    }

    /**
     * @param $paymentId
     *
     * @return array|null
     */
    public function getByPaymentId($paymentId)
    {
        $sql = 'SELECT * FROM ' . _DB_PREFIX_ . 'kevin WHERE payment_id = \'' . pSQL($paymentId) . '\'';
        $row = $this->db->getRow($sql, false);

        return $row ?: null;
    }

    /**
     * @param $orderId
     *
     * @return array|null
     */
    public function getByOrderId($orderId)
    {
        $sql = 'SELECT * FROM ' . _DB_PREFIX_ . 'kevin WHERE id_order = \'' . pSQL($orderId) . '\'';
        $row = $this->db->getRow($sql, false);

        return $row ?: null;
    }

    public function updateOrderId($paymentId, $orderId)
    {
        $this->db->update('kevin', ['id_order' => $orderId], 'payment_id = \'' . pSQL($paymentId) . '\'');
    }

    public function updatePaymentStatus($paymentId, $status)
    {
        $this->db->update('kevin', ['status_group' => $status], 'payment_id = \'' . pSQL($paymentId) . '\'');
    }

    public function tryLockPayment($paymentId)
    {
        $lockToken = uniqid('', true);
        $paymentId = pSQL($paymentId);
        $lockToken = pSQL($lockToken);
        $table = _DB_PREFIX_ . 'kevin';

        $sql = "UPDATE $table SET lock_token = '$lockToken' WHERE payment_id = '$paymentId' AND lock_token IS NULL;";
        $this->db->execute($sql, false);

        $sql = "SELECT lock_token FROM $table WHERE payment_id = '$paymentId' AND lock_token = '$lockToken';" ;
        return (bool) $this->db->getRow($sql, false);
    }
}
