<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin\Setup;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Configuration;
use KevinPlugin\GatewaySettings;
use KevinPlugin\Utils\Translator;
use Language;
use OrderState;
use PrestaShop\PrestaShop\Adapter\Validate;

class KevinOrderStatusSetup
{
    public static function install()
    {
        foreach (self::getKevinOrderStatuses() as $statusKey => $statusConfig) {
            if ($orderStateId = Configuration::get($statusKey)) {
                $orderState = new OrderState($orderStateId);
                foreach (Language::getLanguages(false) as $language) {
                    $statusConfig = self::getKevinOrderStatuses()[$statusKey];
                    $orderState->name[$language['id_lang']] = Translator::translate($statusConfig['name'], $language['iso_code']);
                }
                $orderState->save();
                continue;
            }
            $orderState = new OrderState();
            $orderState->module_name = \Kevin::MODULE_NAME;
            $orderState->color = $statusConfig['color'];
            $orderState->send_email = false;
            $orderState->paid = $statusConfig['paid'];
            $orderState->name = [];
            $orderState->delivery = false;
            $orderState->logable = false;
            $orderState->hidden = false;
            foreach (Language::getLanguages(false) as $language) {
                $orderState->name[$language['id_lang']] = Translator::translate($statusConfig['name'], $language['iso_code']);
            }
            $orderState->add();

            Configuration::updateValue($statusKey, $orderState->id);
        }
    }

    public static function uninstall()
    {
        foreach (self::getKevinOrderStatuses() as $statusKey => $statusConfig) {
            $orderStatusId = Configuration::get($statusKey);
            if ($orderStatusId) {
                $orderState = new OrderState($orderStatusId);
                if (Validate::isLoadedObject($orderState)) {
                    try {
                        $orderState->delete();
                    } catch (\Exception $e) {
                    }
                }
            }
            Configuration::deleteByName($statusKey);
        }
    }

    private static function getKevinOrderStatuses()
    {
        return [
            GatewaySettings::KEVIN_ORDER_STATUS_STARTED => [
                'send_email' => false,
                'name' => 'Payment started',
                'color' => 'Lavender',
                'paid' => false,
            ],
            GatewaySettings::KEVIN_ORDER_STATUS_PENDING => [
                'send_email' => false,
                'name' => 'Payment pending',
                'color' => 'Orchid',
                'paid' => false,
            ],
            GatewaySettings::KEVIN_ORDER_STATUS_PARTIAL_REFUND => [
                'send_email' => false,
                'name' => 'Partially Refunded',
                'color' => 'Green',
                'paid' => false,
            ],
        ];
    }
}
