<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin\Utils;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Context;

class Translator
{
    private static $translations = [];

    /**
     * @param mixed|string $text
     *
     * @return mixed|string
     *
     * @throws \Exception
     */
    public static function translate($text, $iso = null)
    {
        if (!is_string($text)) {
            return $text;
        }
        $iso = $iso ?: Context::getContext()->language->iso_code;
        if (!isset(self::$translations[$iso])) {
            $translationFile = __DIR__ . "/../../translations-kevin/$iso.php";
            $_ = [];
            if (file_exists($translationFile)) {
                include $translationFile;
            }
            self::$translations[$iso] = $_;
        }

        if (isset(self::$translations[$iso][$text])) {
            return self::$translations[$iso][$text];
        }

        return \Translate::getModuleTranslation(\Kevin::MODULE_NAME, $text, \Kevin::MODULE_NAME);
    }
}
