<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace KevinPlugin\View\Payment17;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Context;
use Kevin;
use KevinPlugin\Gateway;
use KevinPlugin\GatewaySettings;
use KevinPlugin\Utils\Translator;
use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

class CardPaymentOptionBuilder
{
    /**
     * @param Gateway $gateway
     *
     * @return PaymentOption
     *
     * @throws \SmartyException
     */
    public static function build(Gateway $gateway, GatewaySettings $gatewaySettings)
    {
        $alerts = [];
        if ($gateway->isSandbox()) {
            $alerts[] = Translator::translate('kevin. payment gateway is in test mode for testing purposes. Real payments are not available.');
        }

        Context::getContext()->smarty->assign([
            'alerts' => $alerts,
        ]);

        $option = new PaymentOption();
        $option->setModuleName(kevin::MODULE_NAME);
        $option->setCallToActionText(Translator::translate('Credit/Debit card'));
        $option->setAdditionalInformation(Context::getContext()->smarty->fetch('module:kevin/views/templates/front/ps17/card-payment-option.tpl'));
        $option->setLogo('https://cdn.kevin.eu/banks/images/VISA_MC.png');
        $option->setAction(Context::getContext()->link->getModuleLink(kevin::MODULE_NAME, 'redirect', ['id' => 'card'], true));

        return $option;
    }
}
