<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */


namespace KevinPluginFramework\Presentation\Admin\Form\BuildGuideline;

use KevinPluginFramework\Presentation\Admin\Form\Validator\NotBlankValidator;

class CheckoutSettingsFormBuildGuideline implements FormBuildGuidelineInterface
{
    const FIELD_NAME_TITLE = 'title';
    const FIELD_NAME_DESCRIPTION = 'description';
    const FIELD_NAME_CHECKOUT_VIEW = 'checkout_view';
    const FIELD_NAME_COUNTRY_DROPDOWN = 'country_dropdown';
    const FIELD_NAME_BANK_SEARCH = 'bank_search';
    const FIELD_NAME_WHITE_BANK_LOGOS = 'white_bank_logos';

    const CHECKOUT_VIEW_OPTION_TILES = 'tiles';
    const CHECKOUT_VIEW_OPTION_LIST = 'list';
    const CHECKOUT_VIEW_OPTION_FRAME = 'frame';

    private $name = 'Checkout view';

    /**
     * @var FormFieldBuildGuideline[]
     */
    private $guidelines;

    public function __construct()
    {
        $this->guidelines = [
            self::FIELD_NAME_CHECKOUT_VIEW => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_CHECKOUT_VIEW)
                ->setTitle('Select checkout view')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setLabel('Select checkout view')
				->setDescription('Choose the one that suits best your storefront design.')
                ->setOptions([
                    self::CHECKOUT_VIEW_OPTION_TILES => 'Tiles',
                    self::CHECKOUT_VIEW_OPTION_LIST => 'List',
                    self::CHECKOUT_VIEW_OPTION_FRAME => 'Redirect to bank selection',
                ]),
            self::FIELD_NAME_COUNTRY_DROPDOWN => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_COUNTRY_DROPDOWN)
                ->setTitle('Country select dropdown')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('Show country selection dropdown on the checkout page.')
                ->setDefault(1),
            self::FIELD_NAME_BANK_SEARCH => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_BANK_SEARCH)
                ->setTitle('Bank search field')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('Show the bank search field on the checkout page.')
                ->setDefault(1),
            self::FIELD_NAME_WHITE_BANK_LOGOS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_WHITE_BANK_LOGOS)
                ->setTitle('Use white bank logos')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_CHECKBOX)
                ->setLabel('If selected bank logos will be shown in white (good for a dark checkout theme)')
                ->setDefault(0),
        ];
    }

    public function getFormFieldBuildGuidelines()
    {
        return $this->guidelines;
    }

    public function getName()
    {
        return $this->name;
    }
}
