/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

try {
	$(document).ready(function () {

		var prestashopRefundButton = $('button[name=partialRefund]');
		if (prestashopRefundButton.length) {
			var prestashopPartialRefundProductInputs = $("[name^='partialRefundProduct[']");
			var prestashopPartialRefundShippingCostInput = $("[name='partialRefundShippingCost']");
			var prestashopPartialRefundProductQuantityInputs = $("[name^='partialRefundProductQuantity[']")
			prestashopRefundButton.closest('.partial_refund_fields').prepend(getRefundKevinSectionHtmlPre176());
		} else {
			var prestashopRefundButton = $('#cancel_product_save');
			var prestashopPartialRefundProductInputs = $("[name^='cancel_product[amount_']")
			var prestashopPartialRefundShippingCostInput = $('#cancel_product_shipping_amount');
			var prestashopPartialRefundProductQuantityInputs = $("[name^='cancel_product[quantity_']")
			$('.refund-checkboxes-container').prepend(getRefundKevinSectionHtmlPost176())
		}

		prestashopRefundButton.on('click', function () {
			setTimeout(() => {
				if (kevinRefundCheckbox.is(':checked')) {
					disableRefundButton();
				}
			}, 5)
		})

		var kevinRefundCheckbox = $('#refundwithkevin');
		var kevinRefundAmountInput = $('#refundwithkevin-amount');
		var kevinRefundAlertExceeds = $('#kevin-refund-alert-exceeds');
		var kevinRefundAlertZero = $('#kevin-refund-alert-zero');
		var kevinRefundAmountWarning = $('#kevin-refund-amount-warning');
		var kevinRefundAmountWarningSpan = $('#kevin-refund-amount-warning-span');

		prestashopPartialRefundProductInputs.on('input', function () {
			checkKevinRefund();
		})
		prestashopPartialRefundShippingCostInput.on('input', function () {
			checkKevinRefund();
		})
		kevinRefundCheckbox.on('input', function () {
			checkKevinRefund();
		})
		prestashopPartialRefundProductQuantityInputs.on('focusout', function () {
			checkKevinRefund();
		})

		function checkKevinRefund()
		{
			hideElement(kevinRefundAlertExceeds);
			hideElement(kevinRefundAlertZero);
			hideElement(kevinRefundAmountWarning);

			if (!kevinRefundCheckbox.is(':checked')) {
				enableRefundButton()
				return;
			}

			if (!validateRefundAmountLessThanOrderAmount()) {
				disableRefundButton()
				showElement(kevinRefundAlertExceeds)
			} else if (!validateRefundAmountMoreThanZero()) {
				disableRefundButton()
				showElement(kevinRefundAlertZero)
			} else {
				enableRefundButton();
				updateKevinRefundAmount();
				showElement(kevinRefundAmountWarning)
			}
		}

		function showElement(element) {
			element.css('display','block');
		}

		function hideElement(element) {
			element.css('display','none');
		}

		function updateKevinRefundAmount() {
			amount = calculateRefundAmount().toFixed(2);
			kevinRefundAmountWarningSpan.text(amount+' '+kevin_order_currency);
			kevinRefundAmountInput.val(amount);
		}

		function validateRefundAmountLessThanOrderAmount() {
			return getMaxAvailableRefundAmount() >= calculateRefundAmount();
		}

		function validateRefundAmountMoreThanZero() {
			return calculateRefundAmount() > 0;
		}

		function calculateRefundAmount() {
			var refundAmount = 0;
			prestashopPartialRefundProductInputs.each(function () {
				var value = $(this).val()
				if (value) {
					refundAmount += parseFloat(value);
				}
			})

			refundAmount += parseFloat(prestashopPartialRefundShippingCostInput.val())

			return refundAmount;
		}

		function getOrderTotal() {
			return parseFloat(kevin_order_total);
		}

		function getMaxAvailableRefundAmount() {
			return parseFloat(kevin_max_refund_amount);
		}

		function disableRefundButton() {
			prestashopRefundButton.prop('disabled',true);
		}

		function enableRefundButton() {
			prestashopRefundButton.prop('disabled',false);
		}
	});
} catch (error) {
	console.log(error);
}

function getRefundKevinSectionHtmlPre176() {
	var html = '<p class="checkbox">';
	html += '<label for="refundwithkevin">';
	html += '<input type="checkbox" id="refundwithkevin" name="refundwithkevin">';
	html += '<input type="hidden" id="refundwithkevin-amount" name="refundwithkevin-amount">';
	html += '<input type="hidden" id="refundwithkevin-token" name="refundwithkevin-token" value="'+ kevin_refund_form_token +'">';
	html += '<strong>' + kevin_text + '</strong>';
	html += '</label>';
	html += '</p>';
	html += getKevinAlertDivs();

	return html;
}

function getRefundKevinSectionHtmlPost176()
{
	var html = `<div class="cancel-product-element form-group kevin-refund" style="display: block;">`;
		html+=	`<div class="checkbox">
					<div class="md-checkbox md-checkbox-inline">
						<label for="refundwithkevin">
						<input type="checkbox" id="refundwithkevin" name="refundwithkevin" class="cancel_product_restock" material_design="material_design">
							<i class="md-checkbox-control"></i>`+kevin_text+`</label>`
		html += '<input type="hidden" id="refundwithkevin-amount" name="refundwithkevin-amount">';
		html += '<input type="hidden" id="refundwithkevin-token" name="refundwithkevin-token" value="'+ kevin_refund_form_token +'">';
		html += `</div>`
		html += `</div>`
		html += getKevinAlertDivs();
		html += `</div>`;

	return html;
}

function getKevinAlertDivs()
{
	var html = '<div class="alert alert-danger" id="kevin-refund-alert-exceeds" style="display: none;">'+kevin_refund_exceeds_text+'</div>'
	html += '<div class="alert alert-danger" id="kevin-refund-alert-zero" style="display: none;">'+kevin_refund_zero_text+'</div>'
	html += '<div class="alert alert-warning" id="kevin-refund-amount-warning" style="display: none;">'+kevin_refund_amount_text + ' <span id="kevin-refund-amount-warning-span"></span></div>'
	return html;
}